@@ -30,17 +30,17 @@
 #include "wx/treectrl.h"
 
 class CertTreeItemData : public wxTreeItemData {
-public:
-	CertTreeItemData(tQSL_Cert cert) : _cert(cert) {}
+ public:
+	explicit CertTreeItemData(tQSL_Cert cert) : _cert(cert) {}
 	~CertTreeItemData();
 	tQSL_Cert getCert() { return _cert; }
 
-private:
+ private:
 	tQSL_Cert _cert;
 };
 
 class CertTree : public wxTreeCtrl {
-public:
+ public:
 	CertTree(wxWindow *parent, const wxWindowID id, const wxPoint& pos,
 		const wxSize& size, long style);
 	virtual ~CertTree();
@@ -48,16 +48,16 @@ public:
 	void OnItemActivated(wxTreeEvent& event);
 	void OnRightDown(wxMouseEvent& event);
 	bool useContextMenu;
-	CertTreeItemData *GetItemData(wxTreeItemId id) { return (CertTreeItemData *)wxTreeCtrl::GetItemData(id); }
+	CertTreeItemData *GetItemData(wxTreeItemId id) { return reinterpret_cast<CertTreeItemData *>(wxTreeCtrl::GetItemData(id)); }
 	int GetNumCerts() const { return _ncerts; }
 	int GetNumIssuers() const { return _nissuers; }
 	void SelectCert(tQSL_Cert cert);
 
-private:
+ private:
+        tQSL_Cert *_certs;
 	int _ncerts;
 	int _nissuers;
 	DECLARE_EVENT_TABLE()
-
 };
 
 #endif	// __certtree_h
