@@ -121,6 +121,9 @@ class MyFrame : public wxFrame {
 	void CheckForUpdates(wxCommandEvent&);
 	void DoCheckForUpdates(bool quiet = false, bool noGUI = false);
 	void UpdateConfigFile(void);
+#ifdef _WIN32
+	void UpdateTQSL(wxString& url);
+#endif
 	void DoCheckExpiringCerts(bool noGUI = false);
 	void OnExpiredCertFound(wxCommandEvent& event);
 
@@ -197,8 +200,9 @@ static const wxLanguage langIds[] = {
     wxLANGUAGE_FRENCH,
     wxLANGUAGE_ITALIAN,
     wxLANGUAGE_GERMAN,
-    wxLANGUAGE_SPANISH,
     wxLANGUAGE_PORTUGUESE,
+    wxLANGUAGE_SPANISH,
+    wxLANGUAGE_CHINESE,
     wxLANGUAGE_JAPANESE,
     wxLANGUAGE_ENGLISH
 };
@@ -210,8 +214,9 @@ const wxString langNames[] = {
     wxT("French"),
     wxT("Italian"),
     wxT("German"),
-    wxT("Spanish"),
     wxT("Portuguese"),
+    wxT("Spanish"),
+    wxT("Chinese"),
     wxT("Japanese"),
     wxT("English")
 };
