@@ -37,7 +37,7 @@ END_EVENT_TABLE()
 
 void
 TQSLWizard::OnPageChanged(wxWizardEvent& ev) {
-	tqslTrace("TQSLWizard::OnPageChanged");
+	tqslTrace("TQSLWizard::OnPageChanged", NULL);
 	(reinterpret_cast<TQSLWizPage *>(GetCurrentPage()))->SetFocus();
 	ExtWizard::OnPageChanged(ev);
 }
@@ -89,7 +89,7 @@ void TQSLWizCertPage::OnSize(wxSizeEvent& ev) {
 
 TQSLWizPage *
 TQSLWizCertPage::GetPrev() const {
-	tqslTrace("TQSLWizCertPage::GetPrev");
+	tqslTrace("TQSLWizCertPage::GetPrev", NULL);
 	int rval;
 
 	tqsl_setStationLocationCapturePage(loc, loc_page);
@@ -102,7 +102,7 @@ TQSLWizCertPage::GetPrev() const {
 
 TQSLWizPage *
 TQSLWizCertPage::GetNext() const {
-	tqslTrace("TQSLWizCertPage::GetNext");
+	tqslTrace("TQSLWizCertPage::GetNext", NULL);
 	TQSLWizPage *newp;
 	bool final = false;
 	int rval;
@@ -204,7 +204,7 @@ TQSLWizCertPage::UpdateFields(int noupdate_field) {
 
 void
 TQSLWizCertPage::OnComboBoxEvent(wxCommandEvent& event) {
-	tqslTrace("TQSLWizCertPage::OnComboBoxEvent");
+	tqslTrace("TQSLWizCertPage::OnComboBoxEvent", NULL);
 	int control_idx = event.GetId() - TQSL_ID_LOW;
 	if (control_idx < 0 || control_idx >= static_cast<int>(controls.size()))
 		return;
@@ -322,7 +322,7 @@ TQSLWizCertPage::~TQSLWizCertPage() {
 
 const char *
 TQSLWizCertPage::validate() {
-	tqslTrace("TQSLWizCertPage::validate");
+	tqslTrace("TQSLWizCertPage::validate", NULL);
 
 	if (!initialized) return 0;
 	valMsg = wxT("");
@@ -431,7 +431,7 @@ TQSLWizCertPage::validate() {
 
 bool
 TQSLWizCertPage::TransferDataFromWindow() {
-	tqslTrace("TQSLWizCertPage::TransferDataFromWindow");
+	tqslTrace("TQSLWizCertPage::TransferDataFromWindow", NULL);
 
 	tqsl_setStationLocationCapturePage(loc, loc_page);
 	for (int i = 0; i < static_cast<int>(controls.size()); i++) {
@@ -469,7 +469,7 @@ END_EVENT_TABLE()
 
 void
 TQSLWizFinalPage::OnListbox(wxCommandEvent &) {
-	tqslTrace("TQSLWizFinalPage::OnListbox");
+	tqslTrace("TQSLWizFinalPage::OnListbox", NULL);
 	if (namelist->GetSelection() >= 0) {
 		const char *cp = (const char *)(namelist->GetClientData(namelist->GetSelection()));
 		if (cp)
@@ -530,7 +530,7 @@ TQSLWizFinalPage::TQSLWizFinalPage(TQSLWizard *parent, tQSL_Location locp, TQSLW
 
 bool
 TQSLWizFinalPage::TransferDataFromWindow() {
-	tqslTrace("TQSLWizFinalPage::TransferDataFromWindow");
+	tqslTrace("TQSLWizFinalPage::TransferDataFromWindow", NULL);
 	validate();
 	if (valMsg.Len() > 0) // Must be a "back"
 		return true;
@@ -552,7 +552,7 @@ TQSLWizFinalPage::OnPageChanging(wxWizardEvent& ev) {
 
 const char *
 TQSLWizFinalPage::validate() {
-	tqslTrace("TQSLWizFinalPage::validate");
+	tqslTrace("TQSLWizFinalPage::validate", NULL);
 	if (!initialized) return 0;
 	wxString val = newname->GetValue().Trim(true).Trim(false);
 	valMsg = wxT("");
